"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var tslib_1 = require("tslib");
var core_1 = require("@angular/core");
var index_1 = require("../index");
var KeyValueService = /** @class */ (function () {
    function KeyValueService(baasicApp) {
        this.baasicApp = baasicApp;
    }
    /**
     * Returns a promise that is resolved once the find action has been performed. Success response returns a list of key value resources matching the given criteria.
     * @param options query resource options object
     * @returns A promise that is resolved once the find action has beend performed.
     * @method
     * @example KeyValueService.find({
                 pageNumber: 1,
                 pageSize: 10,
                 orderBy: '<field>',
                 orderDirection: '<asc|desc>',
                 search: '<search-phrase>'
                })
                .then(function (collection) {
                    // perform success action here
                },
                 function (response, status, headers, config) {
                    // perform error handling here
                });
     **/
    KeyValueService.prototype.find = function (options) {
        return this.baasicApp.keyValueModule.find(options);
    };
    /**
     * Returns a promise that is resolved once the get action has been performed. Success response returns the specified key value resource.
     * @param id unique identifer of key value resources
     * @param options query resource options object
     * @returns A promise that is resolved once the get action has beend performed.
     * @method
     * @example KeyValueService.get('<key-value-id>')
                    .then(function (data) {
                        // perform success action here
                    },
                     function (response, status, headers, config) {
                        // perform error handling here
                    });
     **/
    KeyValueService.prototype.get = function (id, options) {
        return this.baasicApp.keyValueModule.get(id, options);
    };
    /**
     * Returns a promise that is resolved once the create key value action has been performed; this action creates a new key value resource.
     * @param data A key value object that needs to be inserted into the system.
     * @returns A promise that is resolved once the create key value action has beend performed.
     * @method
     * @example KeyValueService.create({key: '<key>', value: '<value>', })
                    .then(function (data) {
                        // perform success action here
                    },
                     function (response, status, headers, config) {
                        // perform error handling here
                    });
     */
    KeyValueService.prototype.create = function (data) {
        return this.baasicApp.keyValueModule.create(data);
    };
    /**
    * Returns a promise that is resolved once the update key value action has been performed; this action updates a key value resource. This route uses HAL enabled objects to obtain routes and therefore it doesn't apply `baasicKeyValueRouteService` route template. Here is an example of how a route can be obtained from HAL enabled objects:
    * ```
    * let params = modelMapper.removeParams(keyValue);
    * let uri = params['model'].links('put').href;
    * ```
    * @param data A key value object used to update specified key value resource.
    * @return A promise that is resolved once the update key value action has been performed.
    * @method
    * @example // keyValue is a resource previously fetched using get action.
                  keyValue.value = '<new-value>';
                  KeyValueService.update(keyValue)
                  .then(function (data) {
                      // perform success action here
                   },
                    function (response, status, headers, config) {
                       // perform error handling here
                   });
    **/
    KeyValueService.prototype.update = function (data) {
        return this.baasicApp.keyValueModule.update(data);
    };
    /**
    * Returns a promise that is resolved once the remove action has been performed. This action will remove a key value resource from the system if successfully completed. This route uses HAL enabled objects to obtain routes and therefore it doesn't apply `baasicKeyValueRouteService` route template. Here is an example of how a route can be obtained from HAL enabled objects:
    * ```
    * let params = modelMapper.removeParams(keyValue);
    * let uri = params['model'].links('delete').href;
    * ```
    * @param data A key value object used to delete specified key value resource.
    * @returns A promise that is resolved once the remove action has been performed.
    * @method
    * @example // keyValue is a resource previously fetched using get action.
                   KeyValueService.remove(keyValue)
                   .then(function (data) {
                       // perform success action here
                   },
                    function (response, status, headers, config) {
                       // perform error handling here
                   });
    **/
    KeyValueService.prototype.remove = function (data) {
        return this.baasicApp.keyValueModule.remove(data);
    };
    KeyValueService = tslib_1.__decorate([
        core_1.Injectable(),
        tslib_1.__metadata("design:paramtypes", [index_1.BaasicAppService])
    ], KeyValueService);
    return KeyValueService;
}());
exports.KeyValueService = KeyValueService;
;
